@@ -1,6 +1,8 @@
 /* g_about.c
  *
- * Copyright (C) 2003 Claudio Girardi
+ * Copyright (C) 2008 Claudio Girardi
+ *           (C) 2006      Edouard Griffiths for modifications implementing
+ *                         averaging mode
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,8 +15,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,7 +46,7 @@ static gchar *gpl_text =
 " 		       Version 2, June 1991\n"
 "\n"
 "  Copyright (C) 1989, 1991 Free Software Foundation, Inc.\n"
-"      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"
+"      51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA\n"
 "  Everyone is permitted to copy and distribute verbatim copies\n"
 "  of this license document, but changing it is not allowed.\n"
 "\n"
@@ -372,7 +374,7 @@ static gchar *gpl_text =
 "     You should have received a copy of the GNU General Public License\n"
 
   "     along with this program; if not, write to the Free Software\n"
-"     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"
+"     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA\n"
 "\n"
 "\n"
 " Also add information on how to contact you by electronic and paper mail.\n"
@@ -405,7 +407,7 @@ static gchar *gpl_text =
 " This General Public License does not permit incorporating your program into\n"
 " proprietary programs.  If your program is a subroutine library, you may\n"
 " consider it more useful to permit linking proprietary applications with the\n"
-" library.  If this is what you want to do, use the GNU Library General\n"
+" library.  If this is what you want to do, use the GNU Lesser General\n"
 " Public License instead of this License.\n"
 "\n"
 ;
@@ -423,7 +425,7 @@ void show_about(GtkWidget * widget, gpointer data)
   }
   about_dialog = gtk_dialog_new();
 
-  gtk_signal_connect(GTK_OBJECT(about_dialog), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_dialog);
+  g_signal_connect(G_OBJECT(about_dialog), "destroy", G_CALLBACK(gtk_widget_destroyed), &about_dialog);
 
   gtk_window_set_wmclass(GTK_WINDOW(about_dialog), "about", "glfer");
   gtk_window_set_title(GTK_WINDOW(about_dialog), "About glfer");
@@ -436,21 +438,19 @@ void show_about(GtkWidget * widget, gpointer data)
   /* ok button */
   bu = gtk_button_new_with_label("Ok");
   gtk_tooltips_set_tip(glfer.tt, bu, "Close window", NULL);
-  gtk_signal_connect_object(GTK_OBJECT(bu), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(about_dialog));
+  g_signal_connect_swapped(G_OBJECT(bu), "clicked", G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(about_dialog));
   GTK_WIDGET_SET_FLAGS(bu, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(about_dialog)->action_area), bu, TRUE, TRUE, 0);
   gtk_widget_grab_default(bu);
   gtk_widget_show(bu);
 
   /* about label */
-  la = gtk_label_new(PACKAGE "\n"
-#ifdef VERSION
-		     "Version " VERSION
-#endif /* VERSION */
+  la = gtk_label_new(PACKAGE_NAME " " PACKAGE_VERSION
 #ifdef RELDATE
-		     " (" RELDATE ")"
+		     "  (" RELDATE ")\n"
 #endif /* RELDATE */
-		     "\n" "(C) by Claudio Girardi, 2001-2003\n" "<in3otd@qsl.net>");
+		     "\n" "(C) 2001-2008 Claudio Girardi, <in3otd@qsl.net>\n"
+		     "\n" "(C) 2006 Edouard Griffiths, <f4exb@free.fr>\n" );
 
   gtk_misc_set_padding(GTK_MISC(la), 40, 40);
 
@@ -464,7 +464,9 @@ void show_about(GtkWidget * widget, gpointer data)
 void show_license(GtkWidget * widget, gpointer data)
 {
   static GdkFont *font = NULL;
-  GtkWidget *bu, *hb, *te, *sb;
+  GtkWidget *bu, *hb, *te, *sw;
+  GtkTextBuffer *b;
+  GtkTextIter end;
 
   if (license_dialog && license_dialog->window) {
     gdk_window_show(license_dialog->window);
@@ -479,7 +481,7 @@ void show_license(GtkWidget * widget, gpointer data)
 
   license_dialog = gtk_dialog_new();
 
-  gtk_signal_connect(GTK_OBJECT(license_dialog), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &license_dialog);
+  g_signal_connect(G_OBJECT(license_dialog), "destroy", G_CALLBACK(gtk_widget_destroyed), &license_dialog);
 
   gtk_window_set_wmclass(GTK_WINDOW(license_dialog), "license", "glfer");
   gtk_window_set_title(GTK_WINDOW(license_dialog), "License");
@@ -492,24 +494,26 @@ void show_license(GtkWidget * widget, gpointer data)
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(license_dialog)->vbox), hb, TRUE, TRUE, 0);
   gtk_widget_show(hb);
 
-  te = gtk_text_new(NULL, NULL);
+  sw = gtk_scrolled_window_new (NULL, NULL);
+  gtk_widget_show(sw);
+  te = gtk_text_view_new();
+  gtk_container_add (GTK_CONTAINER (sw), te);
   gtk_widget_set_usize(te, 81 * gdk_char_width(font, ' '), 400);
-  gtk_text_set_word_wrap(GTK_TEXT(te), FALSE);
+  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (te), GTK_WRAP_WORD);
   gtk_box_pack_start(GTK_BOX(hb), te, TRUE, TRUE, 0);
   gtk_widget_show(te);
-
-  sb = gtk_vscrollbar_new(GTK_TEXT(te)->vadj);
-  gtk_box_pack_start(GTK_BOX(hb), sb, FALSE, FALSE, 0);
-  gtk_widget_show(sb);
+  gtk_box_pack_start(GTK_BOX(hb), sw, FALSE, FALSE, 0);
 
   bu = gtk_button_new_with_label("Ok");
   gtk_tooltips_set_tip(glfer.tt, bu, "Close window", NULL);
   GTK_WIDGET_SET_FLAGS(bu, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(license_dialog)->action_area), bu, TRUE, TRUE, 0);
-  gtk_signal_connect_object(GTK_OBJECT(bu), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(license_dialog));
+  g_signal_connect_swapped(G_OBJECT(bu), "clicked", G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(license_dialog));
   gtk_widget_grab_default(bu);
   gtk_widget_show(bu);
 
   gtk_widget_show(license_dialog);
-  gtk_text_insert(GTK_TEXT(te), font, NULL, NULL, gpl_text, strlen(gpl_text));
+  b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (te));
+  gtk_text_buffer_get_end_iter (b, &end);
+  gtk_text_buffer_insert (b, &end, gpl_text, -1);
 }
