@@ -1,6 +1,8 @@
 /* glfer.c
 
- * Copyright (C) 2001-2003 Claudio Girardi
+ * Copyright (C) 2001-2008 Claudio Girardi
+ *           (C) 2006      Edouard Griffiths for modifications implementing
+ *                         averaging mode
  *
  * Part of this file was inspired by xspectrum, Copyright (C) 2000 Vincent Arkesteijn
  *
@@ -15,8 +17,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.
+ * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 
@@ -35,8 +37,10 @@
 #include "source.h"
 #include "audio.h"
 #include "fft.h"
+#include "avg.h"
 #include "mtm.h"
 #include "hparma.h"
+#include "lmp.h"
 #include "g_main.h"
 #include "qrs.h"
 #include "util.h"
@@ -54,6 +58,8 @@ glfer_t glfer;
 fft_params_t fft_gram_par;
 mtm_params_t mtm_gram_par;
 hparma_params_t hparma_gram_par;
+lmp_params_t lmp_gram_par;
+avg_data_t avgdata;
 
 static int psd_n;
 static char *fname = NULL;
@@ -112,7 +118,7 @@ void show_message(gchar * fmt, ...)
   GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT);
 
   /* Ensure that the dialog box is destroyed when the user clicks ok. */
-  gtk_signal_connect_object(GTK_OBJECT(ok_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(dialog));
+  g_signal_connect_swapped(G_OBJECT(ok_button), "clicked", G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(dialog));
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area), ok_button);
   /* make OK the default button */
   gtk_widget_grab_default(ok_button);
@@ -142,7 +148,7 @@ static void destroy(GtkWidget * widget, gpointer data)
 
 static void help(char *name)
 {
-  fprintf(stderr, "%s, by IN3OTD, Version " VERSION " (" RELDATE ")\n" 
+  fprintf(stderr, "%s, by IN3OTD, Version " PACKAGE_VERSION " (" RELDATE ")\n" 
 	  "Usage: %s [options]\n" 
 	  "Options:\n"
           "\n"
@@ -153,7 +159,7 @@ static void help(char *name)
 	  "  -h, --help              print this help.\n" 
           "  -v, --version           display the version of glfer and exit.\n", name, name);
   fprintf(stderr, "\n");
-  fprintf(stderr, "Mail bug reports and suggestions to <in3otd@qsl.net>\n");
+  fprintf(stderr, "Mail bug reports and suggestions to <" PACKAGE_BUGREPORT "\n");
   fprintf(stderr, "\n");
   exit(1);
 }
@@ -171,8 +177,9 @@ static void version()
 {
   fprintf(stderr,
 	  /* State the canonical name for the program */
-	  "glfer " VERSION " (" RELDATE ")\n" 
-	  "Copyright (C) 2003 Claudio Girardi <in3otd@qsl.net>\n" 
+	  "glfer " PACKAGE_VERSION " (" RELDATE ")\n" 
+	  "Copyright (C) 2008 Claudio Girardi <in3otd@qsl.net>\n" 
+	  "\n"
 	  "This program is distributed in the hope that it will be useful,\n" 
 	  "but WITHOUT ANY WARRANTY; without even the implied warranty of\n" 
 	  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" 
@@ -228,21 +235,22 @@ int main(int argc, char *argv[])
   GtkWidget *window;
   int dev_status = 0;
 
-  opt.fft_n = 1024;
-  opt.fft_overlap = 0.5;
-  opt.fft_a = 0.0; /* with 0.0 we have the classical periodogram, otherwise 0.001 ia a good starting value */
-  opt.fft_limiter = 0;
+  opt.data_block_size = 1024;
+  opt.data_blocks_overlap = 0.0;
+  opt.limiter_a = 0.0; /* with 0.0 we have the classical periodogram, otherwise 0.001 ia a good starting value */
+  opt.enable_limiter = 0;
 
-  opt.mtm_n = 1024;
+  /* MTM parameters */
   opt.mtm_w = 4.0; /* this is actually N * W, according to Thompson notation */
-  opt.mtm_k = 2 * opt.mtm_w;	/* number of windows */
-  opt.mtm_overlap = 0.5;
+  opt.mtm_k = (2 * opt.mtm_w) - 1;	/* number of windows */
 
-  opt.hparma_n = 1024;
-  opt.hparma_overlap = 0.5;
+  /* HP ARMA parameters */
   opt.hparma_p_e = 16;
   opt.hparma_t = 96;
 
+  /* LMP parameters */
+  opt.lmp_av = 4;
+
   opt.sample_rate = 8000;
   opt.dot_time = 500.0;
   opt.ptt_delay = 100.0;
@@ -264,6 +272,11 @@ int main(int argc, char *argv[])
   strcpy(opt.audio_device, "/dev/dsp");
   opt.window_type = 7;
   opt.thr_level = 0.0;
+  opt.autoscale = 1;  /* autoscale as default, otherwise may be confusing for a new user */
+  opt.max_level_db = -3.0;        
+  opt.min_level_db = -23.0;       
+  opt.min_avgband = 400.0;        
+  opt.max_avgband = 1200.0;       
 
   /* well, this should be more elegant... */
   if (parse_rcfile() == 0)
@@ -271,14 +284,29 @@ int main(int argc, char *argv[])
   else
     rc_file_read_ok = FALSE;
 
+
+  /* ...there's no internationalization support at present, so suppress unnecessary warnings */
+  gtk_disable_setlocale ();
+
   gtk_init(&argc, &argv);
 
-  parse_args(argc, argv, &opt.audio_device, &opt.sample_rate, &opt.fft_n);
+  parse_args(argc, argv, &opt.audio_device, &opt.sample_rate, &opt.data_block_size);
+
+  if (opt.avgsamples <= 0)
+    opt.avgsamples = 4;
+  //init_avg(&avgdata); // EG - What's the purpose ? CG
+  //delete_avg(&avgdata);
+  //alloc_avg(&avgdata, opt.data_block_size, opt.avgsamples);    
+  
+  
+  glfer.avgfill = 0.0;
+
+  glfer.input_source = SOURCE_NONE; /* may be modified by init_audio() below */
 
   /* the following code sequence for setting the visual and the colormap */
   /* is from the GDK Reference Manual */
   gdk_rgb_init();
-  gtk_widget_set_default_colormap(gdk_rgb_get_cmap());
+  gtk_widget_set_default_colormap(gdk_rgb_get_colormap());
   gtk_widget_set_default_visual(gdk_rgb_get_visual());
 
   /* whole application tooltips */
@@ -309,26 +337,29 @@ int main(int argc, char *argv[])
   change_params(opt.mode);
 
 /*
-  //jason_init(opt.fft_n); FIXME (calls fft.init)
+  //jason_init(opt.data_block_size); FIXME (calls fft.init)
 */
 
-  psd_n = opt.fft_n / 2 + 1;
+  psd_n = opt.data_block_size / 2 + 1;
+
   window = main_window_init(psd_n, 0, (float) opt.sample_rate / 2);
 
-  gtk_signal_connect(GTK_OBJECT(window), "destroy", GTK_SIGNAL_FUNC(destroy), NULL);
+  g_signal_connect(G_OBJECT(window), "destroy", G_CALLBACK(destroy), NULL);
 
   if (glfer.init_done == FALSE) {
     /* there is no valid TX control port */
     if (dev_status == 0) {
       /* no TX control port was defined in the preference file */
-      show_message("No control port is defined for transmitter!\n" 
-		   "Please go to the Settings/Port menu and select a control\n" 
+      show_message("No control port is defined for the transmitter!\n"
+		   "\n"
+		   "Please go to the Settings/Port menu and select a control\n"
 		   "device to enable transmission functions.");
     } else {
       /* dev_status = -1 */
       /* we tried to open a TX control port but without success */
       /* show a warning message */
       show_message("Open %s failed !\n" 
+		   "\n"
 		   "Please go to the Settings/Port menu and select a control\n" 
 		   "device to enable transmission functions.", opt.ctrl_device);
     }
